@@ -457,8 +457,8 @@ polygon_generic(Imaging im, int n, Edge *e, int ink, int eofill,
     if (ymin < 0) {
         ymin = 0;
     }
-    if (ymax >= im->ysize) {
-        ymax = im->ysize - 1;
+    if (ymax > im->ysize) {
+        ymax = im->ysize;
     }
 
     /* Process the edge table with a scan line searching for intersections */
@@ -600,7 +600,6 @@ ImagingDrawWideLine(Imaging im, int x0, int y0, int x1, int y1,
     double big_hypotenuse, small_hypotenuse, ratio_max, ratio_min;
     int dxmin, dxmax, dymin, dymax;
     Edge e[4];
-    int vertices[4][2];
 
     DRAWINIT();
 
